# -*- coding: utf-8 -*-
'''
Advanced Interface Switcher Locale
2010-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
'''

from advpowcommon.util.locale import Locale

class AISLocale(Locale):

  def __init__(self):
    Locale.__init__(self)

  def initialize(self):
    self.text_domain = 'advanced-interface-switcher'
    self.current_dict = {'item-Bluetooth': 'Bluetooth',
                         'item-GSM': 'GSM',
                         'item-WLAN': 'WLAN',
                         'On': 'On',
                         'Off': 'Off',
                         'Connected': 'Connected',
                         '<>': '<>',
                         'Connecting': 'Connecting',
                         'Disconnecting': 'Disconnecting',
                         'settings-other': 'Other',
                         'item-gsm-3g+gsm': '3G+GSM',
                         'item-gsm-2g': '2G',
                         'item-gsm-3g': '3G',
                         'item-bluetooth-connectable': 'Connectable',
                         'item-bluetooth-discoverable': 'Discoverable',
                         'item-wlan-stock': 'Stock',
                         'item-wlan-bleeding-edge': 'Bleeding Edge',
                         'show-state-dialog': 'Show dialog on click',
                         'show-sa-icon': 'Show icon in status area',
                         'enable-on-startup': 'Enable on startup',
                         'mode-on-startup': 'Enabled mode on startup',
                         'show-popups': 'Show popups',
                         'show-connection-dialog': 'Show connection dialog',
                         'disconnected-timeout': 'Autodisable',
                         'item--1': 'Never',
                         'item-10': 'After 10 seconds',
                         'item-30': 'After 30 seconds',
                         'item-60': 'After 1 minute',
                         'item-300': 'After 5 minutes',
                         'show-signal-strength': 'Show signal strength'
                        }

__locale_singleton = AISLocale()

def get(): return __locale_singleton
